AxisLine class

Constructors

AxisLine({LineStyle? bottom, LineStyle? left, LineStyle? top, LineStyle? right, AxisLinePosition position = AxisLinePosition.background})
const

Properties

bottom LineStyle?
final
hashCode int
The hash code for this object.
no setterinherited
left LineStyle?
final
position AxisLinePosition
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top LineStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited