DeluxAxis<T> class

Implementers

Constructors

DeluxAxis({required double tickLength, required TickStyle tickStyle, required LineStyle? gridLineStyle, required TextStyle labelStyle, required String labelFormatter(T label)?, required Widget? labelWidget(T label)?, double xAxisLabelSpace = 20, required Offset labelOffset, required double gapTickLabel, DeluxViewport<T>? viewport})
const

Properties

gapTickLabel double
final
gridLineStyle LineStyle?
final
hashCode int
The hash code for this object.
no setterinherited
labelFormatter String Function(T label)?
final
labelOffset Offset
final
labelStyle TextStyle
final
labelWidget Widget? Function(T label)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tickLength double
final
tickStyle TickStyle
final
viewport DeluxViewport<T>?
final
xAxisLabelSpace double
means the height of the label space when the domain/measure is on the x-axis
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited