TooltipSpec class

Constructors

TooltipSpec({required InlineSpan richMessage, Decoration? decoration, double? verticalOffset, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding})
const

Properties

decoration Decoration?
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsetsGeometry?
final
padding EdgeInsetsGeometry?
final
richMessage InlineSpan
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalOffset double?
final

Methods

build(Widget child) Tooltip
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited