ConfigSeriesBar class

Inheritance

Constructors

ConfigSeriesBar({Color baseColor = Colors.deepPurpleAccent, Color? colorFn(ChartData item, int index)?, Color? fillColorFn(ChartData item, int index)?, Gradient? fillGradientFn(ChartData item, int index)?, double strokeWidthFn(ChartData item, int index)?, Color? strokeColorFn(ChartData item, int index)?, Gradient? strokeGradientFn(ChartData item, int index)?, TooltipSpec? tooltipSpecFn(ChartData item, int index)?, LabelSpec? labelSpecFn(ChartData item, int index)?, BackgroundSpec? backgroundSpecFn(ChartData item, int index)?, double? barWidth, BorderRadiusGeometry? borderRadiusFn(ChartData item, int index)?, void onTap(ChartData item)?, LabelPosition? labelPositionFn(ChartData item, int index)?})
const

Properties

backgroundSpecFn BackgroundSpec? Function(ChartData item, int index)?
finalinherited
barWidth double?
width of bar element
final
baseColor Color
set color for entire chart element
finalinherited
borderRadiusFn BorderRadiusGeometry? Function(ChartData item, int index)?
set corner radius
final
colorFn Color? Function(ChartData item, int index)?
set color dynamic based on given parameter
finalinherited
fillColorFn Color? Function(ChartData item, int index)?
if chart has shape to be draw, this color is to fill that shape
finalinherited
fillGradientFn Gradient? Function(ChartData item, int index)?
if chart has shape to be draw, this gradient will be set
finalinherited
hashCode int
The hash code for this object.
no setterinherited
labelPositionFn LabelPosition? Function(ChartData item, int index)?
final
labelSpecFn LabelSpec? Function(ChartData item, int index)?
finalinherited
onTap → void Function(ChartData item)?
final
renderType RenderType
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColorFn Color? Function(ChartData item, int index)?
if chart has shape to be draw, this color as border of that shape
finalinherited
strokeGradientFn Gradient? Function(ChartData item, int index)?
set stroke color for shape or path
finalinherited
strokeWidthFn double Function(ChartData item, int index)?
dynamic thickness for stroke
finalinherited
tooltipSpecFn TooltipSpec? Function(ChartData item, int index)?
finalinherited

Methods

draw(ChartData item, int index) → (Color?, Gradient?, double, Color, Gradient?, TooltipSpec?, LabelSpec?, BackgroundSpec?, BorderRadiusGeometry?, LabelPosition, Widget)
generate(ChartData item, int index) → (Color?, Gradient?, double, Color, Gradient?, TooltipSpec?, LabelSpec?, BackgroundSpec?)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited