DeluxBarChart class

Inheritance

Constructors

DeluxBarChart({Key? key, required List<ChartData> data, DomainAxis? domainAxis, MeasureAxis? measureAxis, bool useSecondaryDomain = false, bool useSecondaryMeasure = false, AxisLine? axisLine, Axis direction = Axis.horizontal, ConfigSeriesBar? configSeriesBar})
const

Properties

axisLine AxisLine?
styling for line in axis, if side style null then will be not visible
finalinherited
configSeries ConfigSeriesBar
no setter
configSeriesBar ConfigSeriesBar?
final
data List<ChartData>
list of chart data
finalinherited
direction Axis
direction for domain axis
finalinherited
domain → ({int count, int initialViewportIndex, List<String> labels, List<String> labelsInViewport, DeluxViewport viewport})
no setterinherited
domainAxis DomainAxis?
config main domain axis
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
measure → ({List<num> labelsInViewport, num max, DeluxViewport<num> viewport, num viewportRange})
no setterinherited
measureAxis MeasureAxis?
config main measure axis
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useSecondaryDomain bool
finalinherited
useSecondaryMeasure bool
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildHorizontal() Widget
inherited
buildVertical() Widget
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
drawHorizontal() Widget
override
drawVertical() Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited