DomainAxis<T> class
Constructors
-
DomainAxis({double tickLength = 5, TickStyle tickStyle = const TickStyle(), LineStyle? gridLineStyle, TextStyle labelStyle = const TextStyle(), String labelFormatter(T label)?, Widget? labelWidget(T label)?, double xAxisLabelSpace = 20, Offset labelOffset = Offset.zero, double gapTickLabel = 5, DeluxViewport<
T> ? viewport}) -
const
Properties
- gapTickLabel → double
-
finalinherited
- gridLineStyle → LineStyle?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelFormatter → String Function(T label)?
-
finalinherited
- labelOffset → Offset
-
finalinherited
- labelStyle → TextStyle
-
finalinherited
- labelWidget → Widget? Function(T label)?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickLength → double
-
finalinherited
- tickStyle → TickStyle
-
finalinherited
-
viewport
→ DeluxViewport<
T> ? -
finalinherited
- xAxisLabelSpace → double
-
means the height of the label space when the domain/measure is on the x-axis
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited