MeasureAxis class
Constructors
-
MeasureAxis({double tickLength = 5, TickStyle tickStyle = const TickStyle(), LineStyle? gridLineStyle, TextStyle labelStyle = const TextStyle(), String labelFormatter(num label)?, Widget? labelWidget(num label)?, double xAxisLabelSpace = 20, Offset labelOffset = Offset.zero, double gapTickLabel = 5, int tickCount = 3, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.end, DeluxViewport<
num> ? viewport}) -
const
Properties
- crossAxisAlignment → CrossAxisAlignment
-
final
- gapTickLabel → double
-
finalinherited
- gridLineStyle → LineStyle?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelFormatter → String Function(num label)?
-
finalinherited
- labelOffset → Offset
-
finalinherited
- labelStyle → TextStyle
-
finalinherited
- labelWidget → Widget? Function(num label)?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickCount → int
-
default: (0, maxMeasure from data)
final
- tickLength → double
-
finalinherited
- tickStyle → TickStyle
-
finalinherited
-
viewport
→ DeluxViewport<
num> ? -
finalinherited
- xAxisLabelSpace → double
-
means the height of the label space when the domain/measure is on the x-axis
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited