LabelSpec class
Constructors
- LabelSpec({String? label, TextStyle? labelStyle, Widget? labelWidget, AlignmentGeometry? labelAlignment, EdgeInsetsGeometry? labelPadding})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- labelAlignment → AlignmentGeometry?
-
final
- labelPadding → EdgeInsetsGeometry?
-
final
- labelStyle → TextStyle?
-
final
- labelWidget → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited